AsyncVictoria
=============

Welcome to `AsyncVictoria <https://github.com/M-o-a-T/asyncvictoria>`__!

This library contains a small async wrapper for submission of data to,
and (rudimentary) reading from, `VictoriaMetrics <https://victoriametrics.com>`__.

Also included:

* A basic unit test
* Test scaffolding, to easily test your own code
* a utility to read the last timestamp, as VictoriaMetrics supports efficient queries
* helper code to interpret RRD / collectd input so that you can feed those
  to VictoriaMetrics
* a couple of example scripts
* a migration tool to migrate data from Akumuli to VictoriaMetrics

Tests and collectd support currently require Trio because (a) anyio doesn't
support subprocesses, (b) UDP socket support in anyio is kindof limited.
